==> apache-seata-2.1.0-incubating-src.tar.gz: apache-seata-2.1.0-incubating-src/compatible/src/main/java/io/seata/core/rpc/netty/RmNettyRemotingClient.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package io.seata.core.rpc.netty;

/**
 * RmNettyRemotingClient
 * Notes: used for Apache ShardingSphere integration
 */
@Deprecated
public class RmNettyRemotingClient {

    private static final org.apache.seata.core.rpc.netty.RmNettyRemotingClient INSTANCE = org.apache.seata.core.rpc.netty.RmNettyRemotingClient.getInstance();

    private static class RmNettyRemotingClientInstance {
        private static final RmNettyRemotingClient INSTANCE = new RmNettyRemotingClient();
    }

    private RmNettyRemotingClient() {
    }

    public static RmNettyRemotingClient getInstance() {
        return RmNettyRemotingClientInstance.INSTANCE;
    }

    public void destroy() {
        INSTANCE.destroy();
    }
}

==> apache-seata-2.6.0-incubating-src.tar.gz: apache-seata-2.6.0-incubating-src/compatible/src/main/java/io/seata/core/rpc/netty/RmNettyRemotingClient.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package io.seata.core.rpc.netty;

/**
 * RmNettyRemotingClient
 * Notes: used for Apache ShardingSphere integration
 */
@Deprecated
public class RmNettyRemotingClient {

    private static final org.apache.seata.core.rpc.netty.RmNettyRemotingClient INSTANCE =
            org.apache.seata.core.rpc.netty.RmNettyRemotingClient.getInstance();

    private static class RmNettyRemotingClientInstance {
        private static final RmNettyRemotingClient INSTANCE = new RmNettyRemotingClient();
    }

    private RmNettyRemotingClient() {}

    public static RmNettyRemotingClient getInstance() {
        return RmNettyRemotingClientInstance.INSTANCE;
    }

    public void destroy() {
        INSTANCE.destroy();
    }
}
